==> piwigo-2.10.2.zip: piwigo/plugins/AdminTools/language/ko_KR/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2015 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['Combine JS&CSS'] = 'JS&amp;CSS 합치기';
$lang['Debug languages'] = '언어 디버그하기';
$lang['Debug template'] = '템플릿 디버그하기';
$lang['Give access to quick edit to photo owners even if they are not admin'] = '사진 소유자에게 관리자가 아니더라도 빠른 편집 권한을 줍니다.';
$lang['Save visit in history'] = '방문기록 저장하기';
$lang['Open toolbar by default'] = '기본으로 툴바 열기';
$lang['Properties page'] = '속성 페이지';
$lang['Quick edit'] = '빠른 편집';
$lang['Revert'] = '되돌리기';
$lang['Save'] = '저장하기';
$lang['Saved'] = '저장됨';
$lang['Show SQL queries'] = 'SQL 쿼리 보기';
$lang['left'] = '왼쪽';
$lang['right'] = '오른쪽';

==> piwigo-16.1.0.zip: piwigo/plugins/AdminTools/language/ko_KR/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2015 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['Combine JS&CSS'] = 'JS&amp;CSS 합치기';
$lang['Debug languages'] = '언어 디버그하기';
$lang['Debug template'] = '템플릿 디버그하기';
$lang['Give access to quick edit to photo owners even if they are not admin'] = '사진 소유자에게 관리자가 아니더라도 빠른 편집 권한을 줍니다.';
$lang['Save visit in history'] = '방문기록 저장하기';
$lang['Open toolbar by default'] = '기본으로 툴바 열기';
$lang['Properties page'] = '속성 페이지';
$lang['Quick edit'] = '빠른 편집';
$lang['Revert'] = '되돌리기';
$lang['Save'] = '저장하기';
$lang['Saved'] = '저장됨';
$lang['Show SQL queries'] = 'SQL 쿼리 보기';
$lang['left'] = '왼쪽';
$lang['right'] = '오른쪽';
$lang['Closed icon position'] = '닫음 아이콘 위치';
$lang['View as'] = '보기방식';
$lang['Viewing as <b>%s</b>.'] = '<b>%s</b> 방식으로 보기';
